jinjyaml
========

:Release: |release|
:Version: |version|
:Date:    |today|

Application specific YAML tag of Jinja2 template.

Contents
--------

.. toctree::
   :maxdepth: 1
   :caption: Docs

   README <README>
   AUTHORS <AUTHORS>
   CHANGELOG <CHANGELOG>

.. toctree::
   :caption: APIs

   apidoc/modules



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
